==> HTML-Menu-TreeView-1.07.tar.gz: HTML-Menu-TreeView-1.07/httpdocs/style/Crystal/128/html-menu-treeview/preload.js <==
var folderClosed = new Image(128,128);
folderClosed.src='/style/Crystal/128/html-menu-treeview/folder.png';
var plusNode = new Image(128,128);
plusNode.src='/style/Crystal/128/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(128,128);
lastPlusNode.src='/style/Crystal/128/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(128,128);
clasicPlusNode.src='/style/Crystal/128/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(128,128);
clasicLastPlusNode.src='/style/Crystal/128/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folder_man.png';
var folderGray = new Image(128,128);
folderGray.src='/style/Crystal/128/html-menu-treeview/folderGray.gif';
var folderGreen = new Image(128,128);
folderGreen.src='/style/Crystal/128/html-menu-treeview/folderGreen.gif';
var folderViolet = new Image(128,128);
folderViolet.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(128,128);
folderYellowClosed.src='/style/Crystal/128/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(128,128);
folderOrangeClosed.src='/style/Crystal/128/html-menu-treeview/folder_orange.png';
var folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folder_man.png';
var folderHtmlClosed = new Image(128,128);
folderHtmlClosed.src='/style/Crystal/128/html-menu-treeview/folder_html.png';
var folderFavoriteClosed = new Image(128,128);
folderFavoriteClosed.src='/style/Crystal/128/html-menu-treeview/folder_favorite.png';
var folderTextClosed = new Image(128,128);
folderTextClosed.src='/style/Crystal/128/html-menu-treeview/folder_text.png';
var folderLockedClosed = new Image(128,128);
folderLockedClosed.src='/style/Crystal/128/html-menu-treeview/folder_locked.png';
var folderCrystalClosed = new Image(128,128);
folderCrystalClosed.src='/style/Crystal/128/html-menu-treeview/folder_crystal.png';
var folderVideoClosed = new Image(128,128);
folderVideoClosed.src='/style/Crystal/128/html-menu-treeview/folder_video.png';
var folderPrintClosed = new Image(128,128);
folderPrintClosed.src='/style/Crystal/128/html-menu-treeview/folder_print.png';
var folderImageClosed = new Image(128,128);
folderImageClosed.src='/style/Crystal/128/html-menu-treeview/folder_image.png';
var folderSoundClosed = new Image(128,128);
folderSoundClosed.src='/style/Crystal/128/html-menu-treeview/folder_sound.png';
var folderImportantClosed = new Image(128,128);
folderImportantClosed.src='/style/Crystal/128/html-menu-treeview/folder_important.png';
var folderTarClosed = new Image(128,128);
folderTarClosed.src='/style/Crystal/128/html-menu-treeview/folder_tar.png';

==> HTML-Menu-TreeView-1.22.tar.gz: HTML-Menu-TreeView-1.22/httpdocs/style/Crystal/128/html-menu-treeview/preload.js <==
var folderClosed = new Image(128,128);
folderClosed.src='/style/Crystal/128/html-menu-treeview/folder.png';
var plusNode = new Image(128,128);
plusNode.src='/style/Crystal/128/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(128,128);
lastPlusNode.src='/style/Crystal/128/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(128,128);
clasicPlusNode.src='/style/Crystal/128/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(128,128);
clasicLastPlusNode.src='/style/Crystal/128/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folder_man.png';
var folderGray = new Image(128,128);
folderGray.src='/style/Crystal/128/html-menu-treeview/folder_gray.png';
var folderGreen = new Image(128,128);
folderGreen.src='/style/Crystal/128/html-menu-treeview/folder_green.png';
var folderViolet = new Image(128,128);
folderViolet.src='/style/Crystal/128/html-menu-treeview/folder_violet.png';
var folderYellowClosed = new Image(128,128);
folderYellowClosed.src='/style/Crystal/128/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(128,128);
folderOrangeClosed.src='/style/Crystal/128/html-menu-treeview/folder_orange.png';
var folderManClosed = new Image(128,128);
folderManClosed.src='/style/Crystal/128/html-menu-treeview/folder_man.png';
var folderHtmlClosed = new Image(128,128);
folderHtmlClosed.src='/style/Crystal/128/html-menu-treeview/folder_html.png';
var folderFavoriteClosed = new Image(128,128);
folderFavoriteClosed.src='/style/Crystal/128/html-menu-treeview/folder_favorite.png';
var folderTextClosed = new Image(128,128);
folderTextClosed.src='/style/Crystal/128/html-menu-treeview/folder_txt.png';
var folderLockedClosed = new Image(128,128);
folderLockedClosed.src='/style/Crystal/128/html-menu-treeview/folder_locked.png';
var folderCrystalClosed = new Image(128,128);
folderCrystalClosed.src='/style/Crystal/128/html-menu-treeview/folder_crystal.png';
var folderVideoClosed = new Image(128,128);
folderVideoClosed.src='/style/Crystal/128/html-menu-treeview/folder_video.png';
var folderPrintClosed = new Image(128,128);
folderPrintClosed.src='/style/Crystal/128/html-menu-treeview/folder_print.png';
var folderImageClosed = new Image(128,128);
folderImageClosed.src='/style/Crystal/128/html-menu-treeview/folder_image.png';
var folderSoundClosed = new Image(128,128);
folderSoundClosed.src='/style/Crystal/128/html-menu-treeview/folder_sound.png';
var folderImportantClosed = new Image(128,128);
folderImportantClosed.src='/style/Crystal/128/html-menu-treeview/folder_important.png';
var folderTarClosed = new Image(128,128);
folderTarClosed.src='/style/Crystal/128/html-menu-treeview/folder_tar.png';
